==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QBuffer_shell.h <==
#ifndef QBUFFER_SHELL_H
#define QBUFFER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCore/qbuffer.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBuffer_shell : public QBuffer, public QtJambiShellInterface
{
public:
    QBuffer_shell(QByteArray* buf0, QObject* parent1 = nullptr);
    QBuffer_shell(QObject* parent0 = nullptr);
    ~QBuffer_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& arg__1) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode openMode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool seek(qint64 off0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBuffer_access : public QBuffer
{
    jboolean __qt_atEnd(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canReadLine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_disconnectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint openMode0);
    jlong __qt_pos(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0);
    jboolean __qt_seek_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong off0);
    jlong __qt_size(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0);
};

#endif // QBUFFER_SHELL_H

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QBuffer_shell.h <==
#ifndef QBUFFER_SHELL_H
#define QBUFFER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qbuffer.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBuffer_shell : public QBuffer, public QtJambiShellInterface
{
public:
    QBuffer_shell(QByteArray* buf0, QObject* parent1 = nullptr);
    QBuffer_shell(QObject* parent0 = nullptr);
    ~QBuffer_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& arg__1) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode openMode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool seek(qint64 off0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBuffer_access : public QBuffer
{
    jboolean __qt_atEnd(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canReadLine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_disconnectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint openMode0);
    jlong __qt_pos(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jboolean __qt_seek_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong off0);
    jlong __qt_size(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QBUFFER_SHELL_H
